pub enum ITIP403RegistryErrors {
Unauthorized(Unauthorized),
PolicyNotFound(PolicyNotFound),
PolicyNotSimple(PolicyNotSimple),
InvalidPolicyType(InvalidPolicyType),
IncompatiblePolicyType(IncompatiblePolicyType),
}Expand description
Container for all the ITIP403Registry custom errors.
Variants
PolicyNotFound(PolicyNotFound)
PolicyNotSimple(PolicyNotSimple)
InvalidPolicyType(InvalidPolicyType)
IncompatiblePolicyType(IncompatiblePolicyType)
Implementations
Sourceimpl ITIP403RegistryErrors
impl ITIP403RegistryErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl TIP403RegistryError
impl TIP403RegistryError
Creates an error for unauthorized calls
Sourcepub const fn invalid_policy_type() -> Self
pub const fn invalid_policy_type() -> Self
Creates an error for incompatible policy types
Sourcepub const fn incompatible_policy_type() -> Self
pub const fn incompatible_policy_type() -> Self
Creates an error for incompatible policy types
Sourcepub const fn policy_not_found() -> Self
pub const fn policy_not_found() -> Self
Creates an error for non-existent policy
pub const fn policy_not_simple() -> Self