pub enum ITIP403RegistryEvents {
PolicyAdminUpdated(PolicyAdminUpdated),
PolicyCreated(PolicyCreated),
WhitelistUpdated(WhitelistUpdated),
BlacklistUpdated(BlacklistUpdated),
CompoundPolicyCreated(CompoundPolicyCreated),
ReceivePolicyUpdated(ReceivePolicyUpdated),
}Expand description
Container for all the ITIP403Registry events.
Variants
PolicyAdminUpdated(PolicyAdminUpdated)
PolicyCreated(PolicyCreated)
WhitelistUpdated(WhitelistUpdated)
BlacklistUpdated(BlacklistUpdated)
CompoundPolicyCreated(CompoundPolicyCreated)
ReceivePolicyUpdated(ReceivePolicyUpdated)
Implementations
Sourceimpl ITIP403RegistryEvents
impl ITIP403RegistryEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP403RegistryEvents
impl ITIP403RegistryEvents
Sourcepub fn policy_admin_updated(
policy_id: u64,
updater: Address,
admin: Address,
) -> Self
pub fn policy_admin_updated( policy_id: u64, updater: Address, admin: Address, ) -> Self
Creates a PolicyAdminUpdated event.
event PolicyAdminUpdated(uint64,address,address)Sourcepub fn policy_created(
policy_id: u64,
updater: Address,
policy_type: <PolicyType as SolType>::RustType,
) -> Self
pub fn policy_created( policy_id: u64, updater: Address, policy_type: <PolicyType as SolType>::RustType, ) -> Self
Creates a PolicyCreated event.
event PolicyCreated(uint64,address,uint8)Sourcepub fn whitelist_updated(
policy_id: u64,
updater: Address,
account: Address,
allowed: bool,
) -> Self
pub fn whitelist_updated( policy_id: u64, updater: Address, account: Address, allowed: bool, ) -> Self
Creates a WhitelistUpdated event.
event WhitelistUpdated(uint64,address,address,bool)Sourcepub fn blacklist_updated(
policy_id: u64,
updater: Address,
account: Address,
restricted: bool,
) -> Self
pub fn blacklist_updated( policy_id: u64, updater: Address, account: Address, restricted: bool, ) -> Self
Creates a BlacklistUpdated event.
event BlacklistUpdated(uint64,address,address,bool)Sourcepub fn compound_policy_created(
policy_id: u64,
creator: Address,
sender_policy_id: u64,
recipient_policy_id: u64,
mint_recipient_policy_id: u64,
) -> Self
pub fn compound_policy_created( policy_id: u64, creator: Address, sender_policy_id: u64, recipient_policy_id: u64, mint_recipient_policy_id: u64, ) -> Self
Creates a CompoundPolicyCreated event.
event CompoundPolicyCreated(uint64,address,uint64,uint64,uint64)Sourcepub fn receive_policy_updated(
account: Address,
sender_policy_id: u64,
token_filter_id: u64,
recovery_authority: Address,
) -> Self
pub fn receive_policy_updated( account: Address, sender_policy_id: u64, token_filter_id: u64, recovery_authority: Address, ) -> Self
Creates a ReceivePolicyUpdated event.
event ReceivePolicyUpdated(address,uint64,uint64,address)Trait Implementations
Sourceimpl Clone for ITIP403RegistryEvents
impl Clone for ITIP403RegistryEvents
Sourcefn clone(&self) -> ITIP403RegistryEvents
fn clone(&self) -> ITIP403RegistryEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ITIP403RegistryEvents
impl Debug for ITIP403RegistryEvents
Sourceimpl<'de> Deserialize<'de> for ITIP403RegistryEvents
impl<'de> Deserialize<'de> for ITIP403RegistryEvents
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for ITIP403RegistryEvents
Sourceimpl IntoLogData for ITIP403RegistryEvents
impl IntoLogData for ITIP403RegistryEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl PartialEq for ITIP403RegistryEvents
impl PartialEq for ITIP403RegistryEvents
Sourcefn eq(&self, other: &ITIP403RegistryEvents) -> bool
fn eq(&self, other: &ITIP403RegistryEvents) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ITIP403RegistryEvents
impl Serialize for ITIP403RegistryEvents
Sourceimpl SolEventInterface for ITIP403RegistryEvents
impl SolEventInterface for ITIP403RegistryEvents
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for ITIP403RegistryEvents