pub struct createCompoundPolicyCall {
pub senderPolicyId: u64,
pub recipientPolicyId: u64,
pub mintRecipientPolicyId: u64,
}Expand description
Function with signature createCompoundPolicy(uint64,uint64,uint64) and selector 0x5da414ee.
function createCompoundPolicy(uint64 senderPolicyId, uint64 recipientPolicyId, uint64 mintRecipientPolicyId) external returns (uint64);Fields
senderPolicyId: u64recipientPolicyId: u64mintRecipientPolicyId: u64Trait Implementations
Sourceimpl Clone for createCompoundPolicyCall
impl Clone for createCompoundPolicyCall
Sourcefn clone(&self) -> createCompoundPolicyCall
fn clone(&self) -> createCompoundPolicyCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for createCompoundPolicyCall
impl Debug for createCompoundPolicyCall
Sourceimpl<'de> Deserialize<'de> for createCompoundPolicyCall
impl<'de> Deserialize<'de> for createCompoundPolicyCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonAbiExt for createCompoundPolicyCall
impl JsonAbiExt for createCompoundPolicyCall
Sourceimpl PartialEq for createCompoundPolicyCall
impl PartialEq for createCompoundPolicyCall
Sourceimpl Serialize for createCompoundPolicyCall
impl Serialize for createCompoundPolicyCall
Sourceimpl SolCall for createCompoundPolicyCall
impl SolCall for createCompoundPolicyCall
Sourceconst SIGNATURE: &'static str = "createCompoundPolicy(uint64,uint64,uint64)"
const SIGNATURE: &'static str = "createCompoundPolicy(uint64,uint64,uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>, Uint<64>)
type Parameters<'a> = (Uint<64>, Uint<64>, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<createCompoundPolicyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<createCompoundPolicyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<createCompoundPolicyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<createCompoundPolicyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl Eq for createCompoundPolicyCall
impl StructuralPartialEq for createCompoundPolicyCall